==> estateplat-common-1.1.0-20160901.013915-171-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzDYiq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 地役权
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:23
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_dyiq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzDYiq implements Serializable {
    //权利编号
    @Id
    @XmlElement(name = "qlbh")
    private String qlbh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //供役地不动产单元编号
    @XmlElement(name = "gydbdcdybh")
    private String gydbdcdybh;
    //供役地权利人
    @XmlElement(name = "gydqlr")
    private String gydqlr;
    //供役地权利人证件种类
    @XmlElement(name = "gydqlrzjzl")
    private String gydqlrzjzl;
    //供役地权利人证件号
    @XmlElement(name = "gydqlrzjh")
    private String gydqlrzjh;
    //需役地不动产单元编号
    @XmlElement(name = "xydbdcdybh")
    private String xydbdcdybh;
    //需役地坐落
    @XmlElement(name = "xydzl")
    private String xydzl;
    //需役地权利人
    @XmlElement(name = "xydqlr")
    private String xydqlr;
    //需役地权利人证件种类
    @XmlElement(name = "xydqlrzjzl")
    private String xydqlrzjzl;
    //需役地权利人证件号
    @XmlElement(name = "xydqlrzjh")
    private String xydqlrzjh;
    //地役权内容
    @XmlElement(name = "dyqnr")
    private String dyqnr;
    //权利起始时间
    @XmlElement(name = "qlqssj")
    private Date qlqssj;
    //权利结束时间
    @XmlElement(name = "qljssj")
    private Date qljssj;
    //备注
    @XmlElement(name = "bz")
    private String bz;

    //其他
    @XmlElement(name = "qt")
    private String qt;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getGydbdcdybh() {
        return gydbdcdybh;
    }

    public void setGydbdcdybh(String gydbdcdybh) {
        this.gydbdcdybh = gydbdcdybh;
    }

    public String getGydqlr() {
        return gydqlr;
    }

    public void setGydqlr(String gydqlr) {
        this.gydqlr = gydqlr;
    }

    public String getGydqlrzjzl() {
        return gydqlrzjzl;
    }

    public void setGydqlrzjzl(String gydqlrzjzl) {
        this.gydqlrzjzl = gydqlrzjzl;
    }

    public String getGydqlrzjh() {
        return gydqlrzjh;
    }

    public void setGydqlrzjh(String gydqlrzjh) {
        this.gydqlrzjh = gydqlrzjh;
    }

    public String getXydbdcdybh() {
        return xydbdcdybh;
    }

    public void setXydbdcdybh(String xydbdcdybh) {
        this.xydbdcdybh = xydbdcdybh;
    }

    public String getXydzl() {
        return xydzl;
    }

    public void setXydzl(String xydzl) {
        this.xydzl = xydzl;
    }

    public String getXydqlr() {
        return xydqlr;
    }

    public void setXydqlr(String xydqlr) {
        this.xydqlr = xydqlr;
    }

    public String getXydqlrzjzl() {
        return xydqlrzjzl;
    }

    public void setXydqlrzjzl(String xydqlrzjzl) {
        this.xydqlrzjzl = xydqlrzjzl;
    }

    public String getXydqlrzjh() {
        return xydqlrzjh;
    }

    public void setXydqlrzjh(String xydqlrzjh) {
        this.xydqlrzjh = xydqlrzjh;
    }

    public String getDyqnr() {
        return dyqnr;
    }

    public void setDyqnr(String dyqnr) {
        this.dyqnr = dyqnr;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}

==> estateplat-common-1.2.4-20200917.013406-444-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzDYiq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 地役权
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:23
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_dyiq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzDYiq implements Serializable {
    //权利编号
    @Id
    @XmlElement(name = "qlbh")
    private String qlbh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //供役地不动产单元编号
    @XmlElement(name = "gydbdcdybh")
    private String gydbdcdybh;
    //供役地权利人
    @XmlElement(name = "gydqlr")
    private String gydqlr;
    //供役地权利人证件种类
    @XmlElement(name = "gydqlrzjzl")
    private String gydqlrzjzl;
    //供役地权利人证件号
    @XmlElement(name = "gydqlrzjh")
    private String gydqlrzjh;
    //需役地不动产单元编号
    @XmlElement(name = "xydbdcdybh")
    private String xydbdcdybh;
    //需役地坐落
    @XmlElement(name = "xydzl")
    private String xydzl;
    //需役地权利人
    @XmlElement(name = "xydqlr")
    private String xydqlr;
    //需役地权利人证件种类
    @XmlElement(name = "xydqlrzjzl")
    private String xydqlrzjzl;
    //需役地权利人证件号
    @XmlElement(name = "xydqlrzjh")
    private String xydqlrzjh;
    //地役权内容
    @XmlElement(name = "dyqnr")
    private String dyqnr;
    //权利起始时间
    @XmlElement(name = "qlqssj")
    private Date qlqssj;
    //权利结束时间
    @XmlElement(name = "qljssj")
    private Date qljssj;
    //备注
    @XmlElement(name = "bz")
    private String bz;

    //其他
    @XmlElement(name = "qt")
    private String qt;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;
    //登簿人
    @XmlElement(name = "dbr")
    private String dbr;

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getGydbdcdybh() {
        return gydbdcdybh;
    }

    public void setGydbdcdybh(String gydbdcdybh) {
        this.gydbdcdybh = gydbdcdybh;
    }

    public String getGydqlr() {
        return gydqlr;
    }

    public void setGydqlr(String gydqlr) {
        this.gydqlr = gydqlr;
    }

    public String getGydqlrzjzl() {
        return gydqlrzjzl;
    }

    public void setGydqlrzjzl(String gydqlrzjzl) {
        this.gydqlrzjzl = gydqlrzjzl;
    }

    public String getGydqlrzjh() {
        return gydqlrzjh;
    }

    public void setGydqlrzjh(String gydqlrzjh) {
        this.gydqlrzjh = gydqlrzjh;
    }

    public String getXydbdcdybh() {
        return xydbdcdybh;
    }

    public void setXydbdcdybh(String xydbdcdybh) {
        this.xydbdcdybh = xydbdcdybh;
    }

    public String getXydzl() {
        return xydzl;
    }

    public void setXydzl(String xydzl) {
        this.xydzl = xydzl;
    }

    public String getXydqlr() {
        return xydqlr;
    }

    public void setXydqlr(String xydqlr) {
        this.xydqlr = xydqlr;
    }

    public String getXydqlrzjzl() {
        return xydqlrzjzl;
    }

    public void setXydqlrzjzl(String xydqlrzjzl) {
        this.xydqlrzjzl = xydqlrzjzl;
    }

    public String getXydqlrzjh() {
        return xydqlrzjh;
    }

    public void setXydqlrzjh(String xydqlrzjh) {
        this.xydqlrzjh = xydqlrzjh;
    }

    public String getDyqnr() {
        return dyqnr;
    }

    public void setDyqnr(String dyqnr) {
        this.dyqnr = dyqnr;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}
